---
title: "Getting Started with Render Engine"
description: "An overview of the basics of Render Engine, including creating a simple site, adding pages and collections, and building your site."
date: August 22, 2024
tags: ["getting-started", "basics", "render-engine"]
---

This section will walk you through the basics of Render Engine. It will show you how to create a simple
site and how to add pages and collections to your site.

## Sections

### [Installation]

### [Creating your app]

### [Simple Site Layout]

### [Creating a Page]

### [Creating a Collection]

### [Building your Site]

---

### Continue to [Installation]

[building your site]: building-your-site.md
[creating a collection]: creating-a-collection.md
[creating a page]: creating-a-page.md
[creating your app]: creating-your-app.md
[installation]: installation.md
[simple site layout]: layout.md
